DENOFO Utils
============

The DENOFO Utils module provides utility functions for working with the DENOFO
annotation format and other related tasks distributed over three submodules:

- :mod:`denofo.utils.constants`: Constants used in the DENOFO toolkit.
- :mod:`denofo.utils.helpers`: Helper functions for working with the DENOFO annotation format.
- :mod:`denofo.utils.ncbiTaxDBcheck`: Functions for checking and updating the NCBI Taxonomy Database.


Constants
---------

.. automodule:: denofo.utils.constants
    :members:


Helpers
-------

.. automodule:: denofo.utils.helpers
    :members:


NCBI Taxonomy Database Check
----------------------------

.. automodule:: denofo.utils.ncbiTaxDBcheck
    :members:
